Module accept
http_
types_
2
3.1.0
Module accept
Module Items
Structs
In http_
types_
2::
content
http_types_2
::
content
Module
accept
Client header advertising which media types the client is able to understand.
Structs

Accept
Client header advertising which media types the client is able to understand.
Into
Iter
A borrowing iterator over entries in
Accept
.
Iter
A lending iterator over entries in
Accept
.
IterMut
A mutable iterator over entries in
Accept
.